-- I need isobands

love.window.setTitle( 'isolines-and-isobands-01' )


local tileSize = 200

local function drawGrid()
	love.graphics.setColor(0, 0.5,0)
	local w = math.ceil( love.graphics.getWidth() / tileSize )
	local h = math.ceil( love.graphics.getHeight() / tileSize )
	local width, height = love.graphics.getDimensions()	
	for r=0, w do love.graphics.line(r * tileSize, 0, r * tileSize, height) end	
	for c=0, h do love.graphics.line(0, c * tileSize, width, c * tileSize) end
end




function get_data ()
	local data = { -- pollution in chunks, 3x3
		{  1, 0.6, 0.3},
		{0.9, 0.5, 0.4},
		{0.5, 0.3,   0},
	}
	local result = {}
	for i=1, 2 do
		result[i]={}
		for j=1, 2 do
			result[i][j]=(data[i][j]+data[i+1][j]+data[i][j+1]+data[i+1][j+1])/4
		end
	end
	result.middle=data[2][2]
	return result
end

function get_levels (data)
--	local levels = {0.2, 0.4, 0.6, 0.8}
	local t = 0.05
	local min = 0+t/2
	local max = 1-t/2
	local levels = {}
	for i = min, max, t do
		levels[#levels+1]=i
	end
	return levels
end

function genTextes (data)
	local textes = {}
	for i = 1, #data do
		for j = 1, #data[1] do
			local text = {}
			text.x=i*tileSize
			text.y=j*tileSize
			text.text=data[i][j]
			textes[#textes+1]=text
		end
	end
	return textes
end

function drawTextes(textes)
	for i, text in pairs (textes) do
		love.graphics.print(text.text,text.x,text.y,0)
	end
end

function genMPoints(data, levels)
	local mpoints = {}
	local a,b,c,d,e  = data[1][1], data[1][2], data[2][2], data[2][1], data.middle
	for k, level in pairs (levels) do
		mpoints[level]={}
		
		local xa = tileSize + tileSize*(level-a)/(b-a)
		local ya = tileSize
		table.insert (mpoints[level], xa)
		table.insert (mpoints[level], ya)
		
		local xb = 2*tileSize
		local yb = tileSize + tileSize*(level-b)/(c-b)
		table.insert (mpoints[level], xb)
		table.insert (mpoints[level], yb)
		
		local xc = 2*tileSize - tileSize*(level-c)/(d-c)
		local yc = 2*tileSize
		table.insert (mpoints[level], xc)
		table.insert (mpoints[level], yc)
		
		local xd = tileSize
		local yd = 2*tileSize - tileSize*(level-d)/(a-d)
		table.insert (mpoints[level], xd)
		table.insert (mpoints[level], yd)
	end
	return mpoints
end

function drawMPoints(mpoints)
	love.graphics.setColor(1,1,1)
	for name, points in pairs (mpoints) do
		love.graphics.points(points)
		for j = 1, #points-1, 2 do
			local x = points[j]
			local y = points[j+1]
			love.graphics.print(name, x,y, 1)
		end
	end
end

function drawLines(mpoints)
	love.graphics.setColor(0,1,1)
	for name, points in pairs (mpoints) do
		local line = {}
		for j = 1, #points-1, 2 do
			local x = points[j]
			local y = points[j+1]
			if (x >= tileSize and x <= 2*tileSize) 
				and (y >= tileSize and y <= 2*tileSize) then
				line[#line+1]=x
				line[#line+1]=y
			end
		end
		if #line > 2 then
			love.graphics.line(line)
		end
	end
end

function love.load()
	love.window.setMode( 600, 600)
	local data = get_data ()
	local levels = get_levels (data)
	local textes = genTextes (data)
	
	local mpoints = genMPoints (data, levels)
	
	
	canvas = love.graphics.newCanvas()
	love.graphics.setCanvas(canvas)
		drawGrid()
		drawTextes(textes)
		drawMPoints(mpoints)
		drawLines(mpoints)
	
	love.graphics.setCanvas()
	
--	local data = canvas:newImageData( )
--	data:encode('png')
	
	love.graphics.captureScreenshot( 'file.png' )

end

function love.draw()
	love.graphics.setColor(1,1,1)
	love.graphics.draw(canvas)
end






















